(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 3.0,
MathReader 3.0, or any compatible application. The data for the notebook 
starts with the line of stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[      8687,        360]*)
(*NotebookOutlinePosition[     33042,       1239]*)
(*  CellTagsIndexPosition[     32998,       1235]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["Notebook FibonacciChain3.nb", "Title"],

Cell["(Version 1.0, 18 July 2000, Uwe Grimm)", "Subtitle"],

Cell[CellGroupData[{

Cell["Loading the package", "Section"],

Cell[BoxData[
    \(<< FibonacciChain.m\)], "Input"],

Cell["This lists all functions defined in the package:", "Text"],

Cell[BoxData[
    \(\(?AperiodicTilings`FibonacciChain`*\)\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Fibonacci sequence", "Section"],

Cell[CellGroupData[{

Cell["Substitution rule", "Subsection"],

Cell["\<\
The Fibonacci two-letter substitution rule:
      S -> L
      L -> LS\
\>", "Text"],

Cell[BoxData[
    \(\(?SubstitutionSystem\)\)], "Input"],

Cell[BoxData[
    \(SubstitutionSystem[{"\<S\>" -> {"\<L\>"}, 
        "\<L\>" -> {"\<L\>", "\<S\>"}}, {"\<S\>"}]\)], "Input"],

Cell[BoxData[
    \(\(?SubstitutionRule\)\)], "Input"],

Cell[BoxData[
    \(SubstitutionRule\)], "Input"],

Cell[BoxData[
    \(\(?SubstitutionSequence\)\)], "Input"],

Cell["\<\
This gives the sequence obtained by 8-fold iteration of the rule on \
the initial letter S\
\>", "Text"],

Cell[BoxData[
    \(SubstitutionSequence[8]\)], "Input"],

Cell[BoxData[
    \(\(?SubstitutionWord\)\)], "Input"],

Cell["This gives the same sequence as a single string of letters", "Text"],

Cell[BoxData[
    \(SubstitutionWord[8]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Recursive construction", "Subsection"],

Cell[TextData[{
  "The Fibonacci sequence can also be constrcuted by concatenation of words:\n\
      ",
  Cell[BoxData[
      \(TraditionalForm\`w\_0\)]],
  " = S\n      ",
  Cell[BoxData[
      \(TraditionalForm\`w\_1\)]],
  " = L\n      ",
  Cell[BoxData[
      \(TraditionalForm\`w\_n\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`w\_\(n - 1\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`w\_\(n - 2\)\)]]
}], "Text"],

Cell[BoxData[
    \(\(?FibonacciRecursionSequence\)\)], "Input"],

Cell["\<\
This gives the sequence obtained by 8-fold iteration of the rule on \
the initial letter S\
\>", "Text"],

Cell[BoxData[
    \(FibonacciRecursionSequence[8]\)], "Input"],

Cell[BoxData[
    \(\(?FibonacciRecursionWord\)\)], "Input"],

Cell["This gives the same sequence as a single string of letters", "Text"],

Cell[BoxData[
    \(FibonacciRecursionWord[8]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Counting letters and subwords", "Subsection"],

Cell[BoxData[
    \(\(?LetterCount\)\)], "Input"],

Cell[BoxData[
    \(LetterCount[SubstitutionWord[8]]\)], "Input"],

Cell[BoxData[
    \(LetterCount[SubstitutionWord[8], "\<L\>"]\)], "Input"],

Cell[BoxData[
    \(LetterCount[SubstitutionWord[8], "\<S\>"]\)], "Input"],

Cell[TextData[{
  "These numbers are given by the famous Fibonacci numbers defined by\n     ",
  
  Cell[BoxData[
      \(TraditionalForm\`f\_0\)]],
  " = 0\n     ",
  Cell[BoxData[
      \(TraditionalForm\`f\_1\)]],
  " = 1\n     ",
  Cell[BoxData[
      \(TraditionalForm\`f\_n\)]],
  " = ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\(n - 1\)\)]],
  " + ",
  Cell[BoxData[
      \(TraditionalForm\`f\_\(n - 2\)\)]]
}], "Text"],

Cell[BoxData[
    \(\(?FibonacciNumber\)\)], "Input"],

Cell[BoxData[
    \(FibonacciNumber[9]\)], "Input"],

Cell[BoxData[
    \(FibonacciNumber[8]\)], "Input"],

Cell[BoxData[
    \(FibonacciNumber[7]\)], "Input"],

Cell[BoxData[
    \(\(?LetterFrequency\)\)], "Input"],

Cell[BoxData[
    \(LetterFrequency[SubstitutionWord[8], "\<L\>"]\)], "Input"],

Cell[BoxData[
    \(LetterFrequency[SubstitutionWord[8], "\<S\>"]\)], "Input"],

Cell[BoxData[
    \(\(?SubWordCount\)\)], "Input"],

Cell[BoxData[
    \(SubWordCount[SubstitutionWord[8], SubstitutionWord[3]]\)], "Input"],

Cell[BoxData[
    \(\(?SubWordFrequency\)\)], "Input"],

Cell[BoxData[
    \(SubWordFrequency[SubstitutionWord[8], SubstitutionWord[3]]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Substitution matrix", "Subsection"],

Cell[BoxData[
    \(\(?SubstitutionMatrix\)\)], "Input"],

Cell["\<\
This yields the matrix counting the number of letters of each type \
in the
substitution words\
\>", "Text"],

Cell[BoxData[
    \(SubstitutionMatrix\  // \ MatrixForm\)], "Input"],

Cell["\<\
Its eigenvalues tell you something about the growth of the lengths \
in the
sequence (largest eigenvalue) and the fluctuations of the letter frequencies \
(seond-largest eigenvalue)\
\>", "Text"],

Cell[BoxData[
    \(subeval\  = \ Eigenvalues[SubstitutionMatrix]\)], "Input"],

Cell[BoxData[
    \(Max[subeval]\)], "Input"],

Cell["\<\
The positive eigenvector corresponding to the largest eigenvalue \
yields the frequencies of the letters in the limit sequence (if normalized \
such that the sum of its entries is one)\
\>", "Text"],

Cell[BoxData[
    \(subevec\  = \ Eigensystem[SubstitutionMatrix]\)], "Input"],

Cell[BoxData[
    \(Position[subevec[\([1]\)], Max[subeval]]\)], "Input"],

Cell[BoxData[
    \(subevec\  = \ 
      subevec[\([2, \(Position[subevec[\([1]\)], Max[subeval]]\)[\([1, 1]\)]]
          \)]\)], "Input"],

Cell[BoxData[
    \(subevec\  = \ Simplify[subevec/Apply[Plus, subevec]]\)], "Input"],

Cell[BoxData[
    \(subevec\  // N\)], "Input"],

Cell["\<\
The first number is the frequency of the letter S, the second the \
frequecy of the
letter L. They are related to the golden number (golden mean)\
\>", "Text"],

Cell[BoxData[
    \(GoldenNumber\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["Geometric representation", "Subsection"],

Cell[BoxData[
    \(\(?PlotLinearChain\)\)], "Input"],

Cell[BoxData[
    \(PlotLinearChain[{SubstitutionWord[4]}]\)], "Input"],

Cell[BoxData[
    \(PlotLinearChain[Table[SubstitutionWord[i], {i, 6}]]\)], "Input"],

Cell[BoxData[
    \(PlotLinearChain[Table[SubstitutionWord[i], {i, 6}], True]\)], "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Projection from two-dimensional square lattice", "Section"],

Cell[CellGroupData[{

Cell["\"Strip projection\"", "Subsection"],

Cell[BoxData[
    \(\(?StripProjection\)\)], "Input"],

Cell["Lattice points in the strip are projected.", "Text"],

Cell[BoxData[
    \(StripProjection[20, 1/GoldenRatio, 1.3]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\"Atomic surfaces\"", "Subsection"],

Cell[BoxData[
    \(\(?AtomicSurfaceProjection\)\)], "Input"],

Cell["\<\
Here, each vertex of the square lattice carries an \"atomic surface\
\" attached to it. Points are projeted when the surfaces intersects the \
projection line.\
\>", "Text"],

Cell[BoxData[
    \(AtomicSurfaceProjection[20, 1/GoldenRatio, 1.3]\)], "Input"]
}, Closed]],

Cell[CellGroupData[{

Cell["\"Klotz construction\"", "Subsection"],

Cell[BoxData[
    \(\(?KlotzConstruction\)\)], "Input"],

Cell["\<\
Here, the unit cell of the square lattice is divided into parts \
whose boundaries are parrallel or orthogonal to the projection line \
\>", 
  "Text"],

Cell[BoxData[
    \(KlotzConstruction[20, 1/GoldenRatio, 1.3]\)], "Input"]
}, Closed]]
}, Closed]]
}, Closed]]
},
FrontEndVersion->"X 3.0",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowSize->{780, 745},
WindowMargins->{{Automatic, 87}, {29, Automatic}},
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Section"],
  
  Cell[StyleData[All, "Working"],
    PageWidth->WindowWidth,
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Presentation"],
    PageWidth->WindowWidth,
    ScriptMinSize->12,
    FontSize->16],
  
  Cell[StyleData[All, "Condensed"],
    PageWidth->WindowWidth,
    CellBracketOptions->{"Margins"->{1, 1},
    "Widths"->{0, 5}},
    ScriptMinSize->8,
    FontSize->11],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    ScriptMinSize->5,
    FontSize->10,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Section"],
  
  Cell["\<\
The options defined for the style below will be used at the \
Notebook level.\
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              ValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headings", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {20, 40}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->36,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Title", "Presentation"],
    CellMargins->{{24, 10}, {20, 40}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->44,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Title", "Condensed"],
    CellMargins->{{8, 10}, {4, 8}},
    TextAlignment->Center,
    FontSize->20,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {12, 30}},
    TextAlignment->Center,
    FontSize->24,
    FontColor->RGBColor[1, 0, 0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    TextAlignment->Center,
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Subtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    TextAlignment->Center,
    LineSpacing->{1, 0},
    FontSize->36,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Subtitle", "Condensed"],
    CellMargins->{{8, 10}, {4, 4}},
    TextAlignment->Center,
    FontSize->14,
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    TextAlignment->Center,
    FontSize->18,
    FontColor->RGBColor[1, 0, 0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {20, 15}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic"],
  
  Cell[StyleData["Subsubtitle", "Presentation"],
    CellMargins->{{24, 10}, {20, 20}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Subsubtitle", "Condensed"],
    CellMargins->{{8, 10}, {8, 8}},
    FontSize->12],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {12, 8}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{25, Inherited}, {8, 24}},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    CounterIncrements->"Section",
    CounterAssignments->{{"Subsection", 0}, {"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 0]],
  
  Cell[StyleData["Section", "Presentation"],
    CellMargins->{{40, 10}, {11, 32}},
    LineSpacing->{1, 0},
    FontSize->24],
  
  Cell[StyleData["Section", "Condensed"],
    CellMargins->{{18, Inherited}, {6, 12}},
    FontSize->12],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{13, 0}, {7, 22}},
    FontSize->14]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 20}},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontSize->18,
    FontWeight->"Bold",
    FontColor->RGBColor[1, 0, 1]],
  
  Cell[StyleData["Subsection", "Presentation"],
    CellMargins->{{36, 10}, {11, 32}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Subsection", "Condensed"],
    CellMargins->{{16, Inherited}, {6, 12}}],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{9, 0}, {7, 22}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellDingbat->"\[FilledSmallSquare]",
    CellMargins->{{22, Inherited}, {8, 18}},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Presentation"],
    CellMargins->{{34, 10}, {11, 26}},
    LineSpacing->{1, 0},
    FontSize->18],
  
  Cell[StyleData["Subsubsection", "Condensed"],
    CellMargins->{{17, Inherited}, {6, 12}},
    FontSize->10],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{9, 0}, {7, 14}},
    FontSize->11]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Body Text", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{12, 10}, {7, 7}},
    LineSpacing->{1, 3},
    CounterIncrements->"Text",
    FontSize->18,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Text", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["Text", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 2}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SmallText"],
    CellMargins->{{12, 10}, {6, 6}},
    LineSpacing->{1, 3},
    CounterIncrements->"SmallText",
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["SmallText", "Presentation"],
    CellMargins->{{24, 10}, {8, 8}},
    LineSpacing->{1, 5},
    FontSize->12],
  
  Cell[StyleData["SmallText", "Condensed"],
    CellMargins->{{8, 10}, {5, 5}},
    LineSpacing->{1, 2},
    FontSize->9],
  
  Cell[StyleData["SmallText", "Printout"],
    CellMargins->{{2, 2}, {5, 5}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Input/Output", "Section"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names. Some attributes for these styles are actually set in FormatType Styles \
(in the last section of this stylesheet). \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{45, 10}, {5, 7}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    FontSize->14,
    FontWeight->"Bold"],
  
  Cell[StyleData["Input", "Presentation"],
    CellMargins->{{72, Inherited}, {8, 10}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Input", "Condensed"],
    CellMargins->{{40, 10}, {2, 3}}],
  
  Cell[StyleData["Input", "Printout"],
    CellMargins->{{39, 0}, {4, 6}}]
  }, Open  ]],
  
  Cell[StyleData["InputOnly"],
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    DefaultFormatType->DefaultInputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    CounterIncrements->"Input",
    StyleMenuListing->None,
    FontWeight->"Bold"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{47, 10}, {7, 5}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Output"],
  
  Cell[StyleData["Output", "Presentation"],
    CellMargins->{{72, Inherited}, {10, 8}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Output", "Condensed"],
    CellMargins->{{41, Inherited}, {3, 2}}],
  
  Cell[StyleData["Output", "Printout"],
    CellMargins->{{39, 0}, {6, 4}},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["Message", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Message", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Message", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{45, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{11, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Presentation"],
    CellMargins->{{72, Inherited}, {Inherited, Inherited}},
    LineSpacing->{1, 0}],
  
  Cell[StyleData["Print", "Condensed"],
    CellMargins->{{41, Inherited}, {Inherited, Inherited}}],
  
  Cell[StyleData["Print", "Printout"],
    CellMargins->{{39, Inherited}, {Inherited, Inherited}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{4, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    ImageMargins->{{43, Inherited}, {Inherited, 0}},
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Presentation"],
    ImageMargins->{{62, Inherited}, {Inherited, 0}}],
  
  Cell[StyleData["Graphics", "Condensed"],
    ImageMargins->{{38, Inherited}, {Inherited, 0}},
    Magnification->0.6],
  
  Cell[StyleData["Graphics", "Printout"],
    ImageMargins->{{30, Inherited}, {Inherited, 0}},
    FontSize->9,
    Magnification->0.8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0, 1]],
  
  Cell[StyleData["CellLabel", "Presentation"],
    FontSize->12],
  
  Cell[StyleData["CellLabel", "Condensed"],
    FontSize->9],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontFamily->"Courier",
    FontSize->8,
    FontSlant->"Italic",
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Section"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["InlineFormula"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ScriptLevel->1,
    SingleLetterItalics->True],
  
  Cell[StyleData["InlineFormula", "Presentation"],
    CellMargins->{{24, 10}, {10, 10}},
    LineSpacing->{1, 5}],
  
  Cell[StyleData["InlineFormula", "Condensed"],
    CellMargins->{{8, 10}, {6, 6}},
    LineSpacing->{1, 1}],
  
  Cell[StyleData["InlineFormula", "Printout"],
    CellMargins->{{2, 0}, {6, 6}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    ScriptLevel->0,
    SingleLetterItalics->True,
    UnderoverscriptBoxOptions->{LimitsPositioning->True}],
  
  Cell[StyleData["DisplayFormula", "Presentation"],
    LineSpacing->{1, 5}],
  
  Cell[StyleData["DisplayFormula", "Condensed"],
    LineSpacing->{1, 1}],
  
  Cell[StyleData["DisplayFormula", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Styles for Headers and Footers", "Section"],
  
  Cell[StyleData["Header"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontSize->10,
    FontSlant->"Italic"],
  
  Cell[StyleData["Footer"],
    CellMargins->{{0, 0}, {0, 4}},
    StyleMenuListing->None,
    FontSize->9,
    FontSlant->"Italic"],
  
  Cell[StyleData["PageNumber"],
    CellMargins->{{0, 0}, {4, 1}},
    StyleMenuListing->None,
    FontFamily->"Times",
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Section"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Presentation"]],
  
  Cell[StyleData["Hyperlink", "Condensed"]],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Presentation"]],
  
  Cell[StyleData["MainBookLink", "Condensed"]],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Presentation"]],
  
  Cell[StyleData["AddOnsLink", "Condensed"]],
  
  Cell[StyleData["AddOnLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuideLink", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Presentation"]],
  
  Cell[StyleData["RefGuideLink", "Condensed"]],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Presentation"]],
  
  Cell[StyleData["GettingStartedLink", "Condensed"]],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Presentation"]],
  
  Cell[StyleData["OtherInformationLink", "Condensed"]],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Placeholder Styles", "Section"],
  
  Cell["\<\
The cells below define styles useful for making placeholder \
objects in palette templates.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Placeholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->True,
    StyleMenuListing->None],
  
  Cell[StyleData["Placeholder", "Presentation"]],
  
  Cell[StyleData["Placeholder", "Condensed"]],
  
  Cell[StyleData["Placeholder", "Printout"]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["SelectionPlaceholder"],
    Editable->False,
    Selectable->False,
    StyleBoxAutoDelete->True,
    Placeholder->Primary,
    StyleMenuListing->None,
    DrawHighlighted->True],
  
  Cell[StyleData["SelectionPlaceholder", "Presentation"]],
  
  Cell[StyleData["SelectionPlaceholder", "Condensed"]],
  
  Cell[StyleData["SelectionPlaceholder", "Printout"]]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["FormatType Styles", "Section"],
  
  Cell["\<\
The cells below define styles that are mixed in with the styles \
of most cells.  If a cell's FormatType matches the name of one of the styles \
defined below, then that style is applied between the cell's style and its \
own options. This is particularly true of Input and Output.\
\>", "Text"],
  
  Cell[StyleData["CellExpression"],
    PageWidth->Infinity,
    CellMargins->{{6, Inherited}, {Inherited, Inherited}},
    ShowCellLabel->False,
    ShowSpecialCharacters->False,
    AllowInlineCells->False,
    AutoItalicWords->{},
    StyleMenuListing->None,
    FontFamily->"Courier",
    FontSize->12,
    Background->GrayLevel[1]],
  
  Cell[StyleData["InputForm"],
    AllowInlineCells->False,
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["OutputForm"],
    PageWidth->Infinity,
    TextAlignment->Left,
    LineSpacing->{0.6, 1},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["StandardForm"],
    LineSpacing->{1.25, 0},
    StyleMenuListing->None,
    FontFamily->"Courier"],
  
  Cell[StyleData["TraditionalForm"],
    LineSpacing->{1.25, 0},
    SingleLetterItalics->True,
    TraditionalFunctionNotation->True,
    DelimiterMatching->None,
    StyleMenuListing->None],
  
  Cell["\<\
The style defined below is mixed in to any cell that is in an \
inline cell within another.\
\>", "Text"],
  
  Cell[StyleData["InlineCell"],
    TextAlignment->Left,
    ScriptLevel->1,
    StyleMenuListing->None],
  
  Cell[StyleData["InlineCellEditing"],
    StyleMenuListing->None,
    Background->RGBColor[1, 0.749996, 0.8]]
  }, Closed]]
  }, Open  ]]
  }]
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1731, 51, 44, 0, 104, "Title"],
Cell[1778, 53, 58, 0, 64, "Subtitle"],

Cell[CellGroupData[{
Cell[1861, 57, 38, 0, 61, "Section"],
Cell[1902, 59, 52, 1, 70, "Input"],
Cell[1957, 62, 64, 0, 70, "Text"],
Cell[2024, 64, 71, 1, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[2132, 70, 41, 0, 41, "Section"],

Cell[CellGroupData[{
Cell[2198, 74, 39, 0, 70, "Subsection"],
Cell[2240, 76, 94, 4, 70, "Text"],
Cell[2337, 82, 56, 1, 70, "Input"],
Cell[2396, 85, 126, 2, 70, "Input"],
Cell[2525, 89, 54, 1, 70, "Input"],
Cell[2582, 92, 49, 1, 70, "Input"],
Cell[2634, 95, 58, 1, 70, "Input"],
Cell[2695, 98, 114, 3, 70, "Text"],
Cell[2812, 103, 56, 1, 70, "Input"],
Cell[2871, 106, 54, 1, 70, "Input"],
Cell[2928, 109, 74, 0, 70, "Text"],
Cell[3005, 111, 52, 1, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[3094, 117, 44, 0, 70, "Subsection"],
Cell[3141, 119, 438, 17, 70, "Text"],
Cell[3582, 138, 64, 1, 70, "Input"],
Cell[3649, 141, 114, 3, 70, "Text"],
Cell[3766, 146, 62, 1, 70, "Input"],
Cell[3831, 149, 60, 1, 70, "Input"],
Cell[3894, 152, 74, 0, 70, "Text"],
Cell[3971, 154, 58, 1, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[4066, 160, 51, 0, 70, "Subsection"],
Cell[4120, 162, 49, 1, 70, "Input"],
Cell[4172, 165, 65, 1, 70, "Input"],
Cell[4240, 168, 74, 1, 70, "Input"],
Cell[4317, 171, 74, 1, 70, "Input"],
Cell[4394, 174, 431, 17, 70, "Text"],
Cell[4828, 193, 53, 1, 70, "Input"],
Cell[4884, 196, 51, 1, 70, "Input"],
Cell[4938, 199, 51, 1, 70, "Input"],
Cell[4992, 202, 51, 1, 70, "Input"],
Cell[5046, 205, 53, 1, 70, "Input"],
Cell[5102, 208, 78, 1, 70, "Input"],
Cell[5183, 211, 78, 1, 70, "Input"],
Cell[5264, 214, 50, 1, 70, "Input"],
Cell[5317, 217, 87, 1, 70, "Input"],
Cell[5407, 220, 54, 1, 70, "Input"],
Cell[5464, 223, 91, 1, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[5592, 229, 41, 0, 70, "Subsection"],
Cell[5636, 231, 56, 1, 70, "Input"],
Cell[5695, 234, 118, 4, 70, "Text"],
Cell[5816, 240, 69, 1, 70, "Input"],
Cell[5888, 243, 205, 5, 70, "Text"],
Cell[6096, 250, 78, 1, 70, "Input"],
Cell[6177, 253, 45, 1, 70, "Input"],
Cell[6225, 256, 208, 4, 70, "Text"],
Cell[6436, 262, 78, 1, 70, "Input"],
Cell[6517, 265, 73, 1, 70, "Input"],
Cell[6593, 268, 139, 3, 70, "Input"],
Cell[6735, 273, 85, 1, 70, "Input"],
Cell[6823, 276, 47, 1, 70, "Input"],
Cell[6873, 279, 169, 4, 70, "Text"],
Cell[7045, 285, 45, 1, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7127, 291, 46, 0, 70, "Subsection"],
Cell[7176, 293, 53, 1, 70, "Input"],
Cell[7232, 296, 71, 1, 70, "Input"],
Cell[7306, 299, 84, 1, 70, "Input"],
Cell[7393, 302, 90, 1, 70, "Input"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[7532, 309, 65, 0, 41, "Section"],

Cell[CellGroupData[{
Cell[7622, 313, 42, 0, 70, "Subsection"],
Cell[7667, 315, 53, 1, 70, "Input"],
Cell[7723, 318, 58, 0, 70, "Text"],
Cell[7784, 320, 72, 1, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[7893, 326, 41, 0, 70, "Subsection"],
Cell[7937, 328, 61, 1, 70, "Input"],
Cell[8001, 331, 183, 4, 70, "Text"],
Cell[8187, 337, 80, 1, 70, "Input"]
}, Closed]],

Cell[CellGroupData[{
Cell[8304, 343, 44, 0, 70, "Subsection"],
Cell[8351, 345, 55, 1, 70, "Input"],
Cell[8409, 348, 161, 4, 70, "Text"],
Cell[8573, 354, 74, 1, 70, "Input"]
}, Closed]]
}, Closed]]
}, Closed]]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

